@@ -83,6 +83,13 @@ bool FileTransferJob::moveFileSameFs(const FilePath& srcPath, const GFileInfoPtr
         // do the file operation
         if(!g_file_move(srcPath.gfile().get(), destPath.gfile().get(), GFileCopyFlags(flags), cancellable().get(),
                        nullptr, this, &err)) {
+            // Specially with mounts bound to /mnt, g_file_move() may give the recursive error
+            // and fail, in which case, we ignore the error and try copying and deleting.
+            if(err.code() == G_IO_ERROR_WOULD_RECURSE) {
+              if(auto parent = destPath.parent()) {
+                  return copyFile(srcPath, srcInfo, parent, destPath.baseName().get());
+              }
+            }
             retry = handleError(err, srcPath, srcInfo, destPath, flags);
         }
         else {
@@ -145,7 +152,7 @@ bool FileTransferJob::copySpecialFile(const FilePath& srcPath, const GFileInfoPt
     return ret;
 }
 
-bool FileTransferJob::copyDirContent(const FilePath& srcPath, GFileInfoPtr srcInfo, FilePath& destPath, bool skip) {
+bool FileTransferJob::copyDirContent(const FilePath& srcPath, GFileInfoPtr /*srcInfo*/, FilePath& destPath, bool skip) {
     bool ret = false;
     // copy dir content
     GErrorPtr err;
@@ -279,16 +286,17 @@ bool FileTransferJob::makeDir(const FilePath& srcPath, GFileInfoPtr srcInfo, Fil
                                                          mode, G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,
                                                          cancellable().get(), &err);
                 if(!chmod_done) {
-                    ErrorAction act = emitError(err, ErrorSeverity::MODERATE);
+                    /* NOTE: Some filesystems may not support this. So, ignore errors for now. */
+                    break;
+                    /*ErrorAction act = emitError(err, ErrorSeverity::MODERATE);
                     if(act != ErrorAction::RETRY) {
                         break;
-                    }
-                    /* FIXME: some filesystems may not support this. */
+                    }*/
                 }
             } while(!chmod_done && !isCancelled());
         }
     }
-    return mkdir_done && chmod_done;
+    return mkdir_done/* && chmod_done*/;
 }
 
 bool FileTransferJob::handleError(GErrorPtr &err, const FilePath &srcPath, const GFileInfoPtr &srcInfo, FilePath &destPath, int& flags) {
@@ -375,18 +383,24 @@ bool FileTransferJob::processPath(const FilePath& srcPath, const FilePath& destD
         return false;
     }
 
+    // Use GIO's copy name for destination if existing. This is especially good for copying
+    // from another file system or from places like recent:/// and also handles encoding.
+    const char* destCopyName = g_file_info_get_attribute_string(srcInfo.get(), "standard::copy-name");
+
     bool ret;
     switch(mode_) {
     case Mode::MOVE:
-        ret = moveFile(srcPath, srcInfo, destDirPath, destFileName);
+        ret = moveFile(srcPath, srcInfo, destDirPath, destCopyName ? destCopyName : destFileName);
         break;
     case Mode::COPY: {
         bool deleteSrc = false;
-        ret = copyFile(srcPath, srcInfo, destDirPath, destFileName, deleteSrc);
+        ret = copyFile(srcPath, srcInfo, destDirPath, destCopyName ? destCopyName : destFileName, deleteSrc);
         break;
     }
     case Mode::LINK:
-        ret = linkFile(srcPath, srcInfo, destDirPath, destFileName);
+        ret = linkFile(srcPath, srcInfo, destDirPath,
+                        // see setDestDirPath()
+                        srcPath.isNative() && destCopyName ? destCopyName : destFileName);
         break;
     default:
         ret = false;
