@@ -52,10 +52,12 @@ public:
 
     explicit Folder(const FilePath& path);
 
-    virtual ~Folder();
+    ~Folder() override;
 
     static std::shared_ptr<Folder> fromPath(const FilePath& path);
 
+    static std::shared_ptr<Folder> findByPath(const FilePath& path);
+
     bool makeDirectory(const char* name, GError** error);
 
     void queryFilesystemInfo();
@@ -74,18 +76,14 @@ public:
 
     bool isEmpty() const;
 
+    bool hasFileMonitor() const;
+
     FileInfoList files() const;
 
     const FilePath& path() const;
 
     const std::shared_ptr<const FileInfo> &info() const;
 
-    bool hadCutFilesUnset();
-
-    bool hasCutFiles();
-
-    void setCutFiles(const std::shared_ptr<const HashSet>& cutFilesHashSet);
-
     void forEachFile(std::function<void (const std::shared_ptr<const FileInfo>&)> func) const {
         std::lock_guard<std::mutex> lock{mutex_};
         for(auto it = files_.begin(); it != files_.end(); ++it) {
@@ -187,9 +185,6 @@ private:
     bool defer_content_test : 1;
 
     static std::unordered_map<FilePath, std::weak_ptr<Folder>, FilePathHash> cache_;
-    static QString cutFilesDirPath_;
-    static QString lastCutFilesDirPath_;
-    static std::shared_ptr<const HashSet> cutFilesHashSet_;
     static std::mutex mutex_;
 };
 
