@@ -66,28 +66,16 @@ void IconInfo::updateQIcons() {
     }
 }
 
-QIcon IconInfo::qicon(const bool& transparent) const {
-    if(Q_LIKELY(!transparent)) {
-        if(Q_UNLIKELY(qicon_.isNull() && gicon_)) {
-            if(!G_IS_FILE_ICON(gicon_.get())) {
-                qicon_ = QIcon(new IconEngine{shared_from_this()});
-            }
-            else {
-                qicon_ = getFirst(internalQicons_);
-            }
+QIcon IconInfo::qicon() const {
+    if(Q_UNLIKELY(qicon_.isNull() && gicon_)) {
+        if(!G_IS_FILE_ICON(gicon_.get())) {
+            qicon_ = QIcon(new IconEngine{shared_from_this()});
+        }
+        else {
+            qicon_ = getFirst(internalQicons_);
         }
     }
-    else { // transparent == true
-        if(Q_UNLIKELY(qiconTransparent_.isNull() && gicon_)) {
-            if(!G_IS_FILE_ICON(gicon_.get())) {
-                qiconTransparent_ = QIcon(new IconEngine{shared_from_this(), transparent});
-            }
-            else {
-                qiconTransparent_ = getFirst(internalQicons_);
-            }
-        }
-    }
-    return !transparent ? qicon_ : qiconTransparent_;
+    return qicon_;
 }
 
 QList<QIcon> IconInfo::qiconsFromNames(const char* const* names) {
