@@ -1,12 +1,12 @@
 #include "terminal.h"
 
-namespace Fm {
-
 #include <glib.h>
 #include <gio/gdesktopappinfo.h>
-#include <string.h>
+#include <cstring>
 #include <unistd.h>
 
+namespace Fm {
+
 static std::string defaultTerminalName{"xterm"};
 
 #if !GLIB_CHECK_VERSION(2, 28, 0) && !HAVE_DECL_ENVIRON
