@@ -45,6 +45,8 @@ DirTreeView::DirTreeView(QWidget* parent):
     setContextMenuPolicy(Qt::CustomContextMenu);
     connect(this, &DirTreeView::customContextMenuRequested,
             this, &DirTreeView::onCustomContextMenuRequested);
+
+    setAcceptDrops(true);
 }
 
 DirTreeView::~DirTreeView() {
@@ -208,16 +210,16 @@ void DirTreeView::onCustomContextMenuRequested(const QPoint& pos) {
             action->disconnect();
             action->setData(index);
             connect(action, &QAction::triggered, this, &DirTreeView::onOpen);
-            action = new QAction(QIcon::fromTheme("window-new"), tr("Open in New T&ab"), menu);
+            action = new QAction(QIcon::fromTheme(QStringLiteral("window-new")), tr("Open in New T&ab"), menu);
             action->setData(pathData);
             connect(action, &QAction::triggered, this, &DirTreeView::onNewTab);
             menu->insertAction(menu->separator1(), action);
-            action = new QAction(QIcon::fromTheme("window-new"), tr("Open in New Win&dow"), menu);
+            action = new QAction(QIcon::fromTheme(QStringLiteral("window-new")), tr("Open in New Win&dow"), menu);
             action->setData(pathData);
             connect(action, &QAction::triggered, this, &DirTreeView::onNewWindow);
             menu->insertAction(menu->separator1(), action);
             if(fileInfo->isNative()) {
-                action = new QAction(QIcon::fromTheme("utilities-terminal"), tr("Open in Termina&l"), menu);
+                action = new QAction(QIcon::fromTheme(QStringLiteral("utilities-terminal")), tr("Open in Termina&l"), menu);
                 action->setData(pathData);
                 connect(action, &QAction::triggered, this, &DirTreeView::onOpenInTerminal);
                 menu->insertAction(menu->separator1(), action);
@@ -283,7 +285,7 @@ void DirTreeView::rowsAboutToBeRemoved(const QModelIndex& parent, int start, int
         selIndex = selectionModel()->selectedRows().at(0);
     }
     for (int i = start; i <= end; ++i) {
-        QModelIndex index = parent.child(i, 0);
+        QModelIndex index = model()->index(i, 0, parent);
         if(index.isValid()) {
             if(index == selIndex) {
                 selectionModel()->clear();
