@@ -4,9 +4,12 @@
 #include "utilities.h"
 #include "core/fileinfojob.h"
 #include "ui_filedialog.h"
+#include "filedialog_p.h"
 
 #include <QDialogButtonBox>
 #include <QPushButton>
+#include <QToolButton>
+#include <QMenu>
 #include <QMimeType>
 #include <QMimeDatabase>
 #include <QMessageBox>
@@ -25,12 +28,13 @@ FileDialog::FileDialog(QWidget* parent, FilePath path) :
     folderModel_{nullptr},
     proxyModel_{nullptr},
     folder_{nullptr},
-    options_{0},
+    options_{QFileDialog::Options()},
     viewMode_{FolderView::DetailedListMode},
     fileMode_{QFileDialog::AnyFile},
     acceptMode_{QFileDialog::AcceptOpen},
     confirmOverwrite_{true},
-    modelFilter_{this} {
+    modelFilter_{this},
+    noItemTooltip_{false} {
 
     ui->setupUi(this);
 
@@ -44,6 +48,7 @@ FileDialog::FileDialog(QWidget* parent, FilePath path) :
     connect(ui->sidePane, &SidePane::chdirRequested, [this](int /*type*/, const FilePath &path) {
         setDirectoryPath(path);
     });
+    connect(ui->sidePane, &SidePane::hiddenPlaceSet, this, &FileDialog::onSettingHiddenPlace);
 
     // folder view
     proxyModel_ = new ProxyFolderModel(this);
@@ -137,26 +142,88 @@ FileDialog::FileDialog(QWidget* parent, FilePath path) :
     auto newFolderAction = toolbar->addAction(QIcon::fromTheme(QStringLiteral("folder-new")), tr("Create Folder"));
     connect(newFolderAction, &QAction::triggered, this, &FileDialog::onNewFolder);
     toolbar->addSeparator();
-    // view buttons
-    auto viewModeGroup = new QActionGroup(this);
 
+    // Options menu
+    QMenu* menu = new QMenu(toolbar);
+
+    // view actions
+    auto viewModeGroup = new QActionGroup(this);
     // use generic icons for view actions only if theme icons don't exist
-    iconViewAction_ = toolbar->addAction(QIcon::fromTheme(QLatin1String("view-list-icons"), style()->standardIcon(QStyle::SP_FileDialogContentsView)), tr("Icon View"));
+    iconViewAction_ = menu->addAction(QIcon::fromTheme(QLatin1String("view-list-icons"), style()->standardIcon(QStyle::SP_FileDialogContentsView)), tr("Icon View"));
     iconViewAction_->setCheckable(true);
     connect(iconViewAction_, &QAction::toggled, this, &FileDialog::onViewModeToggled);
     viewModeGroup->addAction(iconViewAction_);
-    thumbnailViewAction_ = toolbar->addAction(QIcon::fromTheme(QLatin1String("view-preview"), style()->standardIcon(QStyle::SP_FileDialogInfoView)), tr("Thumbnail View"));
+    thumbnailViewAction_ = menu->addAction(QIcon::fromTheme(QLatin1String("view-preview"), style()->standardIcon(QStyle::SP_FileDialogInfoView)), tr("Thumbnail View"));
     thumbnailViewAction_->setCheckable(true);
     connect(thumbnailViewAction_, &QAction::toggled, this, &FileDialog::onViewModeToggled);
     viewModeGroup->addAction(thumbnailViewAction_);
-    compactViewAction_ = toolbar->addAction(QIcon::fromTheme(QLatin1String("view-list-text"), style()->standardIcon(QStyle::SP_FileDialogListView)), tr("Compact View"));
+    compactViewAction_ = menu->addAction(QIcon::fromTheme(QLatin1String("view-list-text"), style()->standardIcon(QStyle::SP_FileDialogListView)), tr("Compact View"));
     compactViewAction_->setCheckable(true);
     connect(compactViewAction_, &QAction::toggled, this, &FileDialog::onViewModeToggled);
     viewModeGroup->addAction(compactViewAction_);
-    detailedViewAction_ = toolbar->addAction(QIcon::fromTheme(QLatin1String("view-list-details"), style()->standardIcon(QStyle::SP_FileDialogDetailedView)), tr("Detailed List View"));
+    detailedViewAction_ = menu->addAction(QIcon::fromTheme(QLatin1String("view-list-details"), style()->standardIcon(QStyle::SP_FileDialogDetailedView)), tr("Detailed List View"));
     detailedViewAction_->setCheckable(true);
     connect(detailedViewAction_, &QAction::toggled, this, &FileDialog::onViewModeToggled);
     viewModeGroup->addAction(detailedViewAction_);
+
+    menu->addSeparator();
+
+    // icon size actions
+    QMenu* sizeMenu = new QMenu(tr("Icon Sizes"), toolbar);
+    menu->addMenu(sizeMenu);
+    FileDialogIconSizeAction* bigSizeAction = new FileDialogIconSizeAction(tr("Size of big icons:"), toolbar);
+    bigSizeAction->setBounds(32, 96);
+    connect(bigSizeAction, &FileDialogIconSizeAction::editingFinished, [this, bigSizeAction]() {
+        setBigIconSize(bigSizeAction->value());
+    });
+    sizeMenu->addAction(bigSizeAction);
+
+    FileDialogIconSizeAction* smallSizeAction = new FileDialogIconSizeAction(tr("Size of small icons:"), toolbar);
+    smallSizeAction->setBounds(16, 48);
+    connect(smallSizeAction, &FileDialogIconSizeAction::editingFinished, [this, smallSizeAction]() {
+        setSmallIconSize(smallSizeAction->value());
+    });
+    sizeMenu->addAction(smallSizeAction);
+
+    FileDialogIconSizeAction* thumbnailSizeAction = new FileDialogIconSizeAction(tr("Size of thumbnails:"), toolbar);
+    thumbnailSizeAction->setBounds(64, 256);
+    connect(thumbnailSizeAction, &FileDialogIconSizeAction::editingFinished, [this, thumbnailSizeAction]() {
+        setThumbnailIconSize(thumbnailSizeAction->value());
+    });
+    sizeMenu->addAction(thumbnailSizeAction);
+
+    connect(sizeMenu, &QMenu::aboutToShow, [this, bigSizeAction, smallSizeAction, thumbnailSizeAction]() {
+        bigSizeAction->setValue(bigIconSize());
+        smallSizeAction->setValue(smallIconSize());
+        thumbnailSizeAction->setValue(thumbnailIconSize());
+    });
+
+    menu->addSeparator();
+
+    // thumbnail and tooltip actions
+    auto thumbnailsAction = menu->addAction(tr("Show Thumbnails"));
+    thumbnailsAction->setCheckable(true);
+    connect(thumbnailsAction, &QAction::triggered, [this](bool checked) {
+        setShowThumbnails(checked);
+    });
+    auto tooltipsAction = menu->addAction(tr("Show File Tooltips"));
+    tooltipsAction->setCheckable(true);
+    connect(tooltipsAction, &QAction::triggered, [this](bool checked) {
+        setNoItemTooltip(!checked);
+    });
+    connect(menu, &QMenu::aboutToShow, [this, thumbnailsAction, tooltipsAction]() {
+        thumbnailsAction->setChecked(proxyModel_ ? proxyModel_->showThumbnails() : true);
+        tooltipsAction->setChecked(!noItemTooltip_);
+    });
+
+    // Options menu button
+    auto optionsAction = toolbar->addAction(QIcon::fromTheme(QStringLiteral("preferences-system"), QIcon::fromTheme(QStringLiteral("document-properties"))), tr("Options"));
+    optionsAction->setMenu(menu);
+    // change the popup mode to instant (Qt sets it to MenuButtonPopup)
+    if(QToolButton* optionsBtn = static_cast<QToolButton*>(toolbar->widgetForAction(optionsAction))) {
+        optionsBtn->setPopupMode(QToolButton::InstantPopup);
+    }
+
     ui->toolbarLayout->addWidget(toolbar);
 
     setViewMode(viewMode_);
@@ -172,6 +239,8 @@ FileDialog::FileDialog(QWidget* parent, FilePath path) :
         goHome();
     }
 
+    ui->fileName->installEventFilter(this);
+
     // focus the text entry on showing the dialog
     QTimer::singleShot(0, ui->fileName, SLOT(setFocus()));
 }
@@ -180,6 +249,33 @@ FileDialog::~FileDialog() {
     freeFolder();
 }
 
+bool FileDialog::eventFilter(QObject* watched, QEvent* event) {
+    if (watched == ui->folderView->childView()->viewport() && event->type() == QEvent::ToolTip) {
+        return true;
+    }
+    // Here we make Tab key switch the focus from the main view to the name entry
+    // and BackTab do the reverse because QWidget::setTabOrder() cannot do that.
+    if(event->type() == QEvent::KeyPress) {
+        if(QKeyEvent *ke = static_cast<QKeyEvent*>(event)) {
+            if(watched == ui->folderView->childView() && ui->folderView->childView()->hasFocus()
+               && ke->key() == Qt::Key_Tab && ke->modifiers() == Qt::NoModifier) {
+                ui->fileName->setFocus();
+                // as in Qt -> QLineEdit::focusInEvent()
+                if(!ui->fileName->hasSelectedText()) {
+                    ui->fileName->selectAll();
+                }
+                return true;
+            }
+            if(watched == ui->fileName && ui->fileName->hasFocus()
+               && ke->key() == Qt::Key_Backtab) {
+                ui->folderView->childView()->setFocus();
+                return true;
+            }
+        }
+    }
+    return QDialog::eventFilter(watched, event);
+}
+
 int FileDialog::splitterPos() const {
     return ui->splitter->sizes().at(0);
 }
@@ -191,6 +287,150 @@ void FileDialog::setSplitterPos(int pos) {
     ui->splitter->setSizes(sizes);
 }
 
+int FileDialog::sortColumn() const {
+    if(proxyModel_) {
+        return proxyModel_->sortColumn();
+    }
+    return 0;
+}
+
+Qt::SortOrder FileDialog::sortOrder() const {
+    if(proxyModel_) {
+        return proxyModel_->sortOrder();
+    }
+    return Qt::AscendingOrder;
+}
+
+void FileDialog::sort(int col, Qt::SortOrder order) {
+    if(proxyModel_) {
+        proxyModel_->sort(col, order);
+    }
+}
+
+bool FileDialog::sortFolderFirst() const {
+    if(proxyModel_) {
+        return proxyModel_->folderFirst();
+    }
+    return true;
+}
+
+void FileDialog::setSortFolderFirst(bool value) {
+    if(proxyModel_) {
+        proxyModel_->setFolderFirst(value);
+    }
+}
+
+bool FileDialog::sortHiddenLast() const {
+    if(proxyModel_) {
+        return proxyModel_->hiddenLast();
+    }
+    return false;
+}
+
+void FileDialog::setSortHiddenLast(bool value) {
+    if(proxyModel_) {
+        proxyModel_->setHiddenLast(value);
+    }
+}
+
+bool FileDialog::sortCaseSensitive() const {
+    if(proxyModel_) {
+        return proxyModel_->sortCaseSensitivity() == Qt::CaseSensitive ? true : false;
+    }
+    return false;
+}
+
+void FileDialog::setSortCaseSensitive(bool value) {
+    if(proxyModel_) {
+        proxyModel_->setSortCaseSensitivity(value ? Qt::CaseSensitive : Qt::CaseInsensitive);
+    }
+}
+
+bool FileDialog::showHidden() const {
+    if(proxyModel_) {
+        return proxyModel_->showHidden();
+    }
+    return false;
+}
+
+void FileDialog::setShowHidden(bool showHidden) {
+    if(proxyModel_) {
+        proxyModel_->setShowHidden(showHidden);
+    }
+}
+
+void FileDialog::setHiddenPlaces(const QSet<QString>& items) {
+    ui->sidePane->restoreHiddenPlaces(items);
+    hiddenPlaces_.clear();
+    hiddenPlaces_ = items;
+}
+
+void FileDialog::onSettingHiddenPlace(const QString& str, bool hide) {
+    if(hide) {
+        hiddenPlaces_ << str;
+    }
+    else {
+        hiddenPlaces_.remove(str);
+    }
+}
+
+bool FileDialog::showThumbnails() const {
+    if(proxyModel_) {
+        return proxyModel_->showThumbnails();
+    }
+    return true;
+}
+
+void FileDialog::setShowThumbnails(bool show) {
+    if(proxyModel_) {
+        proxyModel_->setShowThumbnails(show);
+    }
+}
+
+void FileDialog::setNoItemTooltip(bool noItemTooltip) {
+    if(noItemTooltip_ == noItemTooltip) {
+        return;
+    }
+    noItemTooltip_ = noItemTooltip;
+    if(noItemTooltip_) {
+        ui->folderView->childView()->viewport()->installEventFilter(this);
+    }
+    else {
+        ui->folderView->childView()->viewport()->removeEventFilter(this);
+    }
+}
+
+int FileDialog::bigIconSize() const {
+    return ui->folderView->iconSize(FolderView::IconMode).width();
+}
+
+void FileDialog::setBigIconSize(int size) {
+    if(bigIconSize() != size) {
+        ui->folderView->setIconSize(FolderView::IconMode, QSize(size, size));
+    }
+}
+
+int FileDialog::smallIconSize() const {
+    return ui->folderView->iconSize(FolderView::DetailedListMode).width();
+}
+
+void FileDialog::setSmallIconSize(int size) {
+    if(smallIconSize() != size) {
+        ui->folderView->setIconSize(FolderView::DetailedListMode, QSize(size, size));
+        ui->folderView->setIconSize(FolderView::CompactMode, QSize(size, size));
+    }
+}
+
+int FileDialog::thumbnailIconSize() const {
+    return ui->folderView->iconSize(FolderView::ThumbnailMode).width();
+}
+
+void FileDialog::setThumbnailIconSize(int size) {
+    if(thumbnailIconSize() != size) {
+        ui->folderView->setIconSize(FolderView::ThumbnailMode, QSize(size, size));
+    }
+}
+
 // This should always be used instead of getting text directly from the entry.
 QStringList FileDialog::parseNames() const {
     // parse the file names from the text entry
@@ -414,15 +654,15 @@ void FileDialog::setDirectoryPath(FilePath directory, FilePath selectedPath, boo
         return;
     }
 
-   if(directoryPath_ != directory) {
-       if(folder_) {
+    if(directoryPath_ != directory) {
+        if(folder_) {
             if(folderModel_) {
                 proxyModel_->setSourceModel(nullptr);
                 folderModel_->unref(); // unref the cached model
                 folderModel_ = nullptr;
             }
             freeFolder();
-       }
+        }
 
         directoryPath_ = std::move(directory);
 
@@ -444,10 +684,10 @@ void FileDialog::setDirectoryPath(FilePath directory, FilePath selectedPath, boo
 
         QUrl uri = QUrl::fromEncoded(directory.uri().get());
         Q_EMIT directoryEntered(uri);
-   }
+    }
 
     // select the path if valid
-    if(selectedPath.isValid()) {
+    if(selectedPath.isValid() && folder_) {
         if(folder_->isLoaded()) {
             selectFilePathWithDelay(selectedPath);
         }
@@ -461,7 +701,6 @@ void FileDialog::setDirectoryPath(FilePath directory, FilePath selectedPath, boo
         updateAcceptButtonState();
         updateSaveButtonText(false);
     }
-
 }
 
 void FileDialog::selectFilePath(const FilePath &path) {
@@ -583,7 +822,13 @@ void FileDialog::onFileClicked(int type, const std::shared_ptr<const FileInfo> &
                 ui->fileName->clear();
             }
             // chdir into the activated dir
-            setDirectoryPath(file->path());
+            if(file->isMountable() && !file->target().empty()) {
+                // a mounted mountable directory (like computer:///root.link)
+                setDirectoryPath(FilePath::fromPathStr(file->target().c_str()));
+            }
+            else {
+                setDirectoryPath(file->path());
+            }
         }
         else if(fileMode_ != QFileDialog::Directory) {
             // select file(s) and a file item is activated
@@ -798,6 +1043,15 @@ void FileDialog::setViewMode(FolderView::ViewMode mode) {
     connect(ui->folderView->selectionModel(), &QItemSelectionModel::selectionChanged, this, &FileDialog::onSelectionChanged);
     // update selection mode for the view
     updateSelectionMode();
+
+    // FolderView::setViewMode() may delete the view to switch between list and tree.
+    // So, the event filter should be re-installed.
+    ui->folderView->childView()->removeEventFilter(this);
+    ui->folderView->childView()->installEventFilter(this);
+    if(noItemTooltip_) {
+        ui->folderView->childView()->viewport()->removeEventFilter(this);
+        ui->folderView->childView()->viewport()->installEventFilter(this);
+    }
 }
 
 
@@ -1043,7 +1297,7 @@ void FileDialog::FileDialogFilter::update() {
         nameFilter = nameFilter.mid(left, right - left);
     }
     // parse the "*.ext1 *.ext2 *.ext3 ..." list into QRegularExpression objects
-    auto globs = nameFilter.simplified().split(QLatin1Char(' '));
+    const auto globs = nameFilter.simplified().split(QLatin1Char(' '));
     for(const auto& glob: globs) {
 #if (QT_VERSION >= QT_VERSION_CHECK(5,12,0))
         patterns_.emplace_back(QRegularExpression(QStringLiteral("\\A(?:")
