@@ -124,7 +124,7 @@ void FolderViewListView::mouseMoveEvent(QMouseEvent* event) {
                 && (!mouseLeftPressed_
                     // don't start drag if the cursor isn't moved since pressing left mouse button on an item
                     // (because the user may want to scroll the view with mouse wheel before dragging)
-                    || globalItemPressPoint_ == event->globalPos())))) {
+                    || (globalItemPressPoint_ - event->globalPos()).manhattanLength() <= QApplication::startDragDistance())))) {
         bool cursorOnSelectionCorner = cursorOnSelectionCorner_;
         QListView::mouseMoveEvent(event);
         // update the index if the cursor enters/leaves the selection corner icon
@@ -208,46 +208,24 @@ QModelIndex FolderViewListView::indexAt(const QPoint& point) const {
 // TODO: I really should file a bug report to Qt developers.
 
 void FolderViewListView::dragEnterEvent(QDragEnterEvent* event) {
-    if(movement() != Static) {
-        QListView::dragEnterEvent(event);
-    }
-    else {
-        QAbstractItemView::dragEnterEvent(event);
-    }
+    QAbstractItemView::dragEnterEvent(event);
     //qDebug("dragEnterEvent");
     //static_cast<FolderView*>(parent())->childDragEnterEvent(event);
 }
 
 void FolderViewListView::dragLeaveEvent(QDragLeaveEvent* e) {
-    if(movement() != Static) {
-        QListView::dragLeaveEvent(e);
-    }
-    else {
-        QAbstractItemView::dragLeaveEvent(e);
-    }
+    QAbstractItemView::dragLeaveEvent(e);
     static_cast<FolderView*>(parent())->childDragLeaveEvent(e);
 }
 
 void FolderViewListView::dragMoveEvent(QDragMoveEvent* e) {
-    if(movement() != Static) {
-        QListView::dragMoveEvent(e);
-    }
-    else {
-        QAbstractItemView::dragMoveEvent(e);
-    }
+    QAbstractItemView::dragMoveEvent(e);
     static_cast<FolderView*>(parent())->childDragMoveEvent(e);
 }
 
 void FolderViewListView::dropEvent(QDropEvent* e) {
-
     static_cast<FolderView*>(parent())->childDropEvent(e);
-
-    if(movement() != Static) {
-        QListView::dropEvent(e);
-    }
-    else {
-        QAbstractItemView::dropEvent(e);
-    }
+    QAbstractItemView::dropEvent(e);
 }
 
 void FolderViewListView::mouseReleaseEvent(QMouseEvent* event) {
@@ -554,7 +532,8 @@ void FolderViewTreeView::mouseMoveEvent(QMouseEvent* event) {
         else {
             // don't start drag if the cursor isn't moved since pressing left mouse button on an item
             // because the user may want to scroll the view with mouse wheel before dragging
-            if(!(event->buttons() == Qt::LeftButton && globalItemPressPoint_ == event->globalPos())) {
+            if(!(event->buttons() == Qt::LeftButton
+                 && (globalItemPressPoint_ - event->globalPos()).manhattanLength() <= QApplication::startDragDistance())) {
                 QTreeView::mouseMoveEvent(event);
             }
         }
@@ -563,7 +542,8 @@ void FolderViewTreeView::mouseMoveEvent(QMouseEvent* event) {
 
 void FolderViewTreeView::setSelection(const QRect &rect, QItemSelectionModel::SelectionFlags command) {
     if(selectionMode() == QAbstractItemView::ExtendedSelection
-       && model() && state() == QAbstractItemView::DragSelectingState) { // rubberband selection
+       && model() && state() == QAbstractItemView::DragSelectingState
+       && rubberBandRect_.isValid()) { // rubberband selection
         QRect r = rubberBandRect_.adjusted(-horizontalOffset(), -verticalOffset(),
                                             -horizontalOffset(), -verticalOffset());
         r.setLeft(qMax(0, r.left()));
