@@ -27,6 +27,8 @@
 #include <QStandardPaths>
 #include "utilities.h"
 #include "placesmodelitem.h"
+#include "dndactionmenu.h"
+#include "fileoperation.h"
 
 namespace Fm {
 
@@ -39,7 +41,7 @@ PlacesModel::PlacesModel(QObject* parent):
     trashMonitor_(nullptr),
     trashUpdateTimer_(nullptr),
     // FIXME: this seems to be broken when porting to new API.
-    ejectIcon_(QIcon::fromTheme("media-eject")) {
+    ejectIcon_(QIcon::fromTheme(QStringLiteral("media-eject"))) {
     setColumnCount(2);
 
     placesRoot = new QStandardItem(tr("Places"));
@@ -47,7 +49,7 @@ PlacesModel::PlacesModel(QObject* parent):
     placesRoot->setColumnCount(2);
     appendRow(placesRoot);
 
-    homeItem = new PlacesModelItem("user-home", g_get_user_name(), Fm::FilePath::homeDir());
+    homeItem = new PlacesModelItem("user-home", QString::fromUtf8(g_get_user_name()), Fm::FilePath::homeDir());
     placesRoot->appendRow(homeItem);
 
     desktopItem = new PlacesModelItem("user-desktop", tr("Desktop"),
@@ -490,6 +492,10 @@ void PlacesModel::onBookmarksChanged() {
 }
 
 Qt::ItemFlags PlacesModel::flags(const QModelIndex& index) const {
+    if(!index.isValid()) {
+       // alow dropping on empty space (but also see PlacesModel::canDropMimeData)
+       return Qt::ItemIsDropEnabled;
+    }
     if(index.column() == 1) { // make 2nd column of every row selectable.
         return Qt::ItemIsSelectable | Qt::ItemIsEnabled;
     }
@@ -532,9 +538,9 @@ std::shared_ptr<PlacesModel> PlacesModel::globalInstance() {
 
 bool PlacesModel::dropMimeData(const QMimeData* data, Qt::DropAction /*action*/, int row, int column, const QModelIndex& parent) {
     QStandardItem* item = itemFromIndex(parent);
-    if(data->hasFormat("application/x-bookmark-row")) { // the data being dopped is a bookmark row
+    if(data->hasFormat(QStringLiteral("application/x-bookmark-row"))) { // the data being dopped is a bookmark row
         // decode it and do bookmark reordering
-        QByteArray buf = data->data("application/x-bookmark-row");
+        QByteArray buf = data->data(QStringLiteral("application/x-bookmark-row"));
         QDataStream stream(&buf, QIODevice::ReadOnly);
         int oldPos = -1;
         char* pathStr = nullptr;
@@ -571,32 +577,86 @@ bool PlacesModel::dropMimeData(const QMimeData* data, Qt::DropAction /*action*/,
     else if(data->hasUrls()) { // files uris are dropped
         if(row == -1 && column == -1) { // drop uris on an item
             if(item && item->parent()) { // need to be a child item
-                PlacesModelItem* placesItem = static_cast<PlacesModelItem*>(item);
-                if(placesItem->path()) {
-                    qDebug() << "dropped dest:" << placesItem->text();
-                    // TODO: copy or move the dragged files to the dir pointed by the item.
-                    qDebug() << "drop on" << item->text();
+                if (item == trashItem_) {
+                    auto paths = pathListFromQUrls(data->urls());
+                    if(!paths.empty()) {
+                        Qt::DropAction action = DndActionMenu::askUser(Qt::MoveAction, QCursor::pos());
+                        if (action == Qt::MoveAction) {
+                            FileOperation::trashFiles(paths, false);
+                        }
+                    }
                 }
+                else if (item != applicationsItem && item != networkItem  && item != computerItem) {
+                    PlacesModelItem* placesItem = static_cast<PlacesModelItem*>(item);
+                    auto destPath = placesItem->path();
+                    if(destPath) {
+                        Qt::DropAction action = DndActionMenu::askUser(Qt::CopyAction | Qt::MoveAction | Qt::LinkAction, QCursor::pos());
+                        auto paths = pathListFromQUrls(data->urls());
+                        if(!paths.empty()) {
+                            switch(action) {
+                            case Qt::CopyAction:
+                                FileOperation::copyFiles(paths, destPath);
+                                break;
+                            case Qt::MoveAction:
+                                FileOperation::moveFiles(paths, destPath);
+                                break;
+                            case Qt::LinkAction:
+                                FileOperation::symlinkFiles(paths, destPath);
+                            /* Falls through. */
+                            default:
+                                return false;
+                            }
+                            return true;
+                        }
+                    }
+                }
+                return false;
             }
         }
-        else { // drop uris on a position between items
-            if(item == bookmarksRoot) { // we only allow dropping on blank row of bookmarks section
-                auto paths = pathListFromQUrls(data->urls());
-                for(auto& path: paths) {
-                    // FIXME: this is a blocking call
-                    if(g_file_query_file_type(path.gfile().get(), G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,
-                                              nullptr) == G_FILE_TYPE_DIRECTORY) {
-                        auto disp_name = path.baseName();
-                        bookmarks->insert(path, disp_name.get(), row);
-                    }
-                    return true;
+        // Drop uris:
+        // (1) On the root bookmark (row == -1 && column == -1 && item && !item->parent());
+        // (2) Or at a position between items (row != -1 || column != -1);
+        if(item == bookmarksRoot
+           // (3) Or after bookmarks (for users' convenience).
+           || (item == nullptr && row == -1 && column == -1)) {
+            auto paths = pathListFromQUrls(data->urls());
+            for(auto& path: paths) {
+                // FIXME: this is a blocking call
+                if(g_file_query_file_type(path.gfile().get(), G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,
+                                          nullptr) == G_FILE_TYPE_DIRECTORY) {
+                    auto disp_name = path.baseName();
+                    bookmarks->insert(path, QString::fromUtf8(disp_name.get()), row);
                 }
             }
+            return true;
         }
     }
     return false;
 }
 
+bool PlacesModel::canDropMimeData(const QMimeData* data, Qt::DropAction action, int row, int column, const QModelIndex& parent) const {
+    QStandardItem* item = itemFromIndex(parent);;
+    if(item == nullptr && !(row == -1 && column == -1)) {
+        // don't allow dopping (on an empty space) between root items
+        // (dropping between child items is handled by PlacesModel::flags)
+        return false;
+    }
+    if(data->hasFormat(QStringLiteral("application/x-bookmark-row"))) {
+        // as in PlacesModel::dropMimeData
+        bool canDrop = false;
+        if(row == -1 && column == -1) {
+            if(item && item->parent() == bookmarksRoot) {
+                canDrop = true;
+            }
+        }
+        else if(item == bookmarksRoot) {
+            canDrop = true;
+        }
+        return canDrop;
+    }
+    return QStandardItemModel::canDropMimeData(data, action, row, column, parent);
+}
+
 // we only support dragging bookmark items and use our own
 // custom pseudo-mime-type: application/x-bookmark-row
 QMimeData* PlacesModel::mimeData(const QModelIndexList& indexes) const {
@@ -614,7 +674,7 @@ QMimeData* PlacesModel::mimeData(const QModelIndexList& indexes) const {
             // Let's store the pos, name, and path of the bookmark item instead.
             auto pathStr = bookmarkItem->path().toString();
             stream << index.row() << pathStr.get();
-            mime->setData("application/x-bookmark-row", data);
+            mime->setData(QStringLiteral("application/x-bookmark-row"), data);
             return mime;
         }
     }
@@ -622,7 +682,7 @@ QMimeData* PlacesModel::mimeData(const QModelIndexList& indexes) const {
 }
 
 QStringList PlacesModel::mimeTypes() const {
-    return QStringList() << "application/x-bookmark-row" << "text/uri-list";
+    return QStringList() << QStringLiteral("application/x-bookmark-row") << QStringLiteral("text/uri-list");
 }
 
 Qt::DropActions PlacesModel::supportedDropActions() const {
