@@ -26,6 +26,7 @@
 #include <QList>
 #include <QStringBuilder>
 #include <QMessageBox>
+#include <QStandardPaths>
 #include "fileoperation.h"
 #include <QEventLoop>
 
@@ -66,13 +67,15 @@ Fm::FilePathList pathListFromQUrls(QList<QUrl> urls) {
     return pathList;
 }
 
-std::pair<Fm::FilePathList, bool> parseClipboardData(const QMimeData& data) {
-    bool isCut = false;
+void pasteFilesFromClipboard(const Fm::FilePath& destPath, QWidget* parent) {
+    QClipboard* clipboard = QApplication::clipboard();
+    const QMimeData* data = clipboard->mimeData();
     Fm::FilePathList paths;
+    bool isCut = false;
 
-    if(data.hasFormat(QStringLiteral("x-special/gnome-copied-files"))) {
+    if(data->hasFormat(QStringLiteral("x-special/gnome-copied-files"))) {
         // Gnome, LXDE, and XFCE
-        QByteArray gnomeData = data.data(QStringLiteral("x-special/gnome-copied-files"));
+        QByteArray gnomeData = data->data(QStringLiteral("x-special/gnome-copied-files"));
         char* pdata = gnomeData.data();
         char* eol = strchr(pdata, '\n');
 
@@ -83,26 +86,15 @@ std::pair<Fm::FilePathList, bool> parseClipboardData(const QMimeData& data) {
         }
     }
 
-    if(paths.empty() && data.hasUrls()) {
+    if(paths.empty() && data->hasUrls()) {
         // The KDE way
-        paths = Fm::pathListFromQUrls(data.urls());
-        QByteArray cut = data.data(QStringLiteral("application/x-kde-cutselection"));
+        paths = Fm::pathListFromQUrls(data->urls());
+        QByteArray cut = data->data(QStringLiteral("application/x-kde-cutselection"));
         if(!cut.isEmpty() && QChar::fromLatin1(cut.at(0)) == QLatin1Char('1')) {
             isCut = true;
         }
     }
 
-    return std::make_pair(paths, isCut);
-}
-
-void pasteFilesFromClipboard(const Fm::FilePath& destPath, QWidget* parent) {
-    QClipboard* clipboard = QApplication::clipboard();
-    const QMimeData* data = clipboard->mimeData();
-    Fm::FilePathList paths;
-    bool isCut = false;
-
-    std::tie(paths, isCut) = parseClipboardData(*data);
-
     if(!paths.empty()) {
         if(isCut) {
             FileOperation::moveFiles(paths, destPath, parent);
@@ -193,6 +185,37 @@ bool renameFile(std::shared_ptr<const Fm::FileInfo> file, QWidget* parent) {
     return true;
 }
 
+void setDefaultAppForType(const Fm::GAppInfoPtr app, std::shared_ptr<const Fm::MimeType> mimeType) {
+    // NOTE: "g_app_info_set_as_default_for_type()" writes to "~/.config/mimeapps.list"
+    // but we want to set the default app only for the current DE (e.g., LXQt).
+    // More importantly, if the DE-specific list already exists and contains some
+    // default apps, it will have priority over "~/.config/mimeapps.list" and so,
+    // "g_app_info_set_as_default_for_type()" could not change those apps.
+
+    if(app == nullptr || mimeType == nullptr) {
+        return;
+    }
+
+    // first find the DE's mimeapps list file
+    QByteArray mimeappsList = "mimeapps.list";
+    QList<QByteArray> desktopsList = qgetenv("XDG_CURRENT_DESKTOP").toLower().split(':');
+    if(!desktopsList.isEmpty()) {
+        mimeappsList = desktopsList.at(0) + "-" + mimeappsList;
+    }
+    QString configDir = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation);
+    auto mimeappsListPath = CStrPtr(g_build_filename(configDir.toUtf8().constData(),
+                                                     mimeappsList.constData(),
+                                                     nullptr));
+
+    // set the default app in the DE's mimeapps list
+    const char* desktop_id = g_app_info_get_id(app.get());
+    GKeyFile* kf = g_key_file_new();
+    g_key_file_load_from_file(kf, mimeappsListPath.get(), G_KEY_FILE_NONE, nullptr);
+    g_key_file_set_string(kf, "Default Applications", mimeType->name(), desktop_id);
+    g_key_file_save_to_file(kf, mimeappsListPath.get(), nullptr);
+    g_key_file_free(kf);
+}
+
 // templateFile is a file path used as a template of the new file.
 void createFileOrFolder(CreateFileType type, FilePath parentDir, const TemplateItem* templ, QWidget* parent) {
     QString defaultNewName;
